@@ -4,7 +4,7 @@ use warnings;
 package Dist::Zilla::Plugin::CheckExtraTests;
 # ABSTRACT: check xt tests before release
 
-our $VERSION = '0.028'; # from Dist-Zilla-Plugin-CheckExtraTests-0.028.tar.gz
+our $VERSION = '0.029';
 
 # Dependencies
 use Dist::Zilla 4.3 ();
@@ -102,7 +102,7 @@ Dist::Zilla::Plugin::CheckExtraTests - check xt tests before release
 
 =head1 VERSION
 
-version 0.028
+version 0.029
 
 =head1 SYNOPSIS
 
@@ -174,7 +174,7 @@ Jesse Luehrs <doy@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Christopher J. Madsen David H. Adler Karen Etheridge Kent Fredric Olivier Mengué Ricardo Signes
+=for stopwords Christopher J. Madsen David Golden H. Adler Karen Etheridge Kent Fredric Olivier Mengué Ricardo Signes
 
 =over 4
 
@@ -184,6 +184,10 @@ Christopher J. Madsen <cjm@cpan.org>
 
 =item *
 
+David Golden <xdg@xdg.me>
+
+=item *
+
 David H. Adler <dha@pobox.com>
 
 =item *
@@ -206,7 +210,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by David Golden.
+This software is Copyright (c) 2016 by David Golden.
 
 This is free software, licensed under:
 
